@@ -1,9 +1,5 @@
-# -*- coding: utf-8 -*-
-
-from admin_interface.compat import gettext_lazy as _
-
 from django.apps import AppConfig
-from django.db.models.signals import post_migrate
+from django.utils.translation import gettext_lazy as _
 
 
 class AdminInterfaceConfig(AppConfig):
@@ -13,9 +9,6 @@ class AdminInterfaceConfig(AppConfig):
     default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
-
         from admin_interface import settings
-        from admin_interface.models import Theme
 
         settings.check_installed_apps()
-        post_migrate.connect(Theme.post_migrate_handler, sender=self)
