@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
-
 import colorfield.fields
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
